/* Test of setting a custom cursor

   fltk-config --compile cursor_test.cxx

*/

#include <stdio.h>
#include <unistd.h>

#include <FL/Fl.H>
#include <FL/Fl_Group.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Button.H>
#include <FL/Fl_RGB_Image.H>
#include <FL/Fl_Pixmap.H>

static Fl_Double_Window *main_win = NULL;
static Fl_RGB_Image *cursr = NULL;
static bool special_cursor = false;

/* XPM, as generated by The Gimp */
static const char * box_T_xpm[] = {
"17 17 2 1",
" 	c None",
".	c #000000",
"                 ",
" ............... ",
" .      .      . ",
" .      .      . ",
" .      .      . ",
" .      .      . ",
" .      .      . ",
" .      .      . ",
" ............... ",
" .      .      . ",
" .      .      . ",
" .      .      . ",
" .      .      . ",
" .      .      . ",
" .      .      . ",
" ............... ",
"                 "};

class tst_grp : public Fl_Group
{
public:
    tst_grp (int x, int y, int w, int h,const char *L = 0) : Fl_Group(x, y, w, h, L) {}

// Event handling
int handle (int ev)
{
  int res = Fl_Group::handle(ev);

  switch (ev)
  {
    case FL_ENTER:
      if (special_cursor == false)
      {
          special_cursor = true;
          main_win->cursor (cursr, 2, 2);
      }
      res = 1;
      break;

    case FL_LEAVE:
      if (special_cursor != false)
      {
          special_cursor = false;
          main_win->cursor (FL_CURSOR_DEFAULT);
      }
      res = 1;
      break;
    default:
      break;
  }
  return res;
} /* end of handle() method */

}; // tst_grp

static tst_grp *inner = NULL;

static void quit_cb (Fl_Widget *, void *)
{
    if (main_win) main_win->hide();
} // quit_cb

int main(int argc, char **argv)
{
    Fl_Pixmap *pxm = new Fl_Pixmap (box_T_xpm);

    cursr = new Fl_RGB_Image (pxm);

    main_win = new Fl_Double_Window (256, 256, "Test Cursor");
    main_win->begin();
    main_win->box (FL_FLAT_BOX);

    inner = new tst_grp (20, 20, 216, 216);
    inner->box (FL_THIN_DOWN_BOX);
    inner->begin();

    Fl_Button qt_bt (40, 40, 60, 20, "Quit");
    qt_bt.callback (quit_cb, NULL);

    inner->end();

    main_win->end();
    main_win->show (argc, argv);

    return Fl::run();
} // main

/* ENd of file */
